==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/PieSliceDataContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataContextDescriptionMetadata } from "./DataContextDescriptionMetadata";
import { PieSliceDataContextDescription } from "./PieSliceDataContextDescription";
/**
 * @hidden
 */
var PieSliceDataContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PieSliceDataContextDescriptionMetadata, _super);
    function PieSliceDataContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PieSliceDataContextDescriptionMetadata.b = function (a) {
        if (PieSliceDataContextDescriptionMetadata.a == null) {
            PieSliceDataContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PieSliceDataContextDescriptionMetadata.c(PieSliceDataContextDescriptionMetadata.a);
        }
        if (a.g(PieSliceDataContextDescriptionMetadata.a)) {
            return;
        }
        a.s(PieSliceDataContextDescriptionMetadata.a);
    };
    PieSliceDataContextDescriptionMetadata.c = function (a) {
        DataContextDescriptionMetadata.c(a);
        a.item("PercentValue", "Number:double");
        a.item("IsOthersSlice", "Boolean");
    };
    PieSliceDataContextDescriptionMetadata.d = function (a) {
        PieSliceDataContextDescriptionMetadata.b(a);
        a.u("PieSliceDataContext", function () { return new PieSliceDataContextDescription(); });
        a.t("PieSliceDataContext", PieSliceDataContextDescriptionMetadata.a);
    };
    PieSliceDataContextDescriptionMetadata.$t = markType(PieSliceDataContextDescriptionMetadata, 'PieSliceDataContextDescriptionMetadata');
    PieSliceDataContextDescriptionMetadata.a = null;
    return PieSliceDataContextDescriptionMetadata;
}(Base));
export { PieSliceDataContextDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/PieSliceDataContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataContextDescriptionMetadata } from "./DataContextDescriptionMetadata";
import { PieSliceDataContextDescription } from "./PieSliceDataContextDescription";
/**
 * @hidden
 */
var PieSliceDataContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PieSliceDataContextDescriptionMetadata, _super);
    function PieSliceDataContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PieSliceDataContextDescriptionMetadata.b = function (a) {
        if (PieSliceDataContextDescriptionMetadata.a == null) {
            PieSliceDataContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PieSliceDataContextDescriptionMetadata.c(PieSliceDataContextDescriptionMetadata.a);
        }
        if (a.j(PieSliceDataContextDescriptionMetadata.a)) {
            return;
        }
        a.y(PieSliceDataContextDescriptionMetadata.a);
    };
    PieSliceDataContextDescriptionMetadata.c = function (a) {
        DataContextDescriptionMetadata.c(a);
        a.item("PercentValue", "Number:double");
        a.item("IsOthersSlice", "Boolean");
    };
    PieSliceDataContextDescriptionMetadata.d = function (a) {
        PieSliceDataContextDescriptionMetadata.b(a);
        a.aa("PieSliceDataContext", function () { return new PieSliceDataContextDescription(); });
        a.z("PieSliceDataContext", PieSliceDataContextDescriptionMetadata.a);
    };
    PieSliceDataContextDescriptionMetadata.$t = markType(PieSliceDataContextDescriptionMetadata, 'PieSliceDataContextDescriptionMetadata');
    PieSliceDataContextDescriptionMetadata.a = null;
    return PieSliceDataContextDescriptionMetadata;
}(Base));
export { PieSliceDataContextDescriptionMetadata };
